==> dhall-yaml-1.2.11-167-x86_64.pkg.tar.zst: usr/share/haskell/register/dhall-yaml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 dhall-yaml
version:              1.2.11
visibility:           public
id:                   dhall-yaml-1.2.11-LAqHITUbAzZLM41Iv9xfPc
key:                  dhall-yaml-1.2.11-LAqHITUbAzZLM41Iv9xfPc
license:              GPL-3.0-only
copyright:            2019 Gabriel Gonzalez
maintainer:           Gabriel439@gmail.com
author:               Gabriel Gonzalez
synopsis:             Convert between Dhall and YAML
description:
    Use this package if you want to convert between Dhall expressions and YAML.
    You can use this package as a library or an executable:

    * See the "Dhall.Yaml" module if you want to use this package as a library

    * Use the @dhall-to-yaml-ng@ program from this package if you want an executable

category:             Compiler
abi:                  0a3d93ee2c17d2a233760048088b6e30
exposed:              True
exposed-modules:      Dhall.Yaml Dhall.YamlToDhall
import-dirs:          /usr/lib/ghc-9.2.8/site-local/dhall-yaml-1.2.11
library-dirs:         /usr/lib/ghc-9.2.8/site-local/dhall-yaml-1.2.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dhall-yaml
hs-libraries:         HSdhall-yaml-1.2.11-LAqHITUbAzZLM41Iv9xfPc
depends:
    HsYAML-0.2.1.3-Jv3uHMzrE3uE7yCeoL0Kz
    HsYAML-aeson-0.2.0.1-5xydkwG97W9F8ttRJtR5fD
    aeson-2.1.2.1-7dcOSp8IaGA80HTLJplaly base-4.16.4.0
    bytestring-0.11.4.0 dhall-1.41.2-625GfEz7Q7nIFwcwEygMcC
    dhall-json-1.7.11-Jhc1AZSGkFs74MVV5AwHrV
    optparse-applicative-0.17.1.0-Jx8WaQbsFK9BJBRr9ePa2T text-1.2.5.0
    vector-0.13.1.0-BOAscM7GxpQxkvUjpqER4

haddock-interfaces:   /usr/share/doc/dhall-yaml/html/dhall-yaml.haddock
haddock-html:         /usr/share/doc/dhall-yaml/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> dhall-yaml-1.2.11-169-x86_64.pkg.tar.zst: usr/share/haskell/register/dhall-yaml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 dhall-yaml
version:              1.2.11
visibility:           public
id:                   dhall-yaml-1.2.11-DVZnli2ncUyABm15qqoFRp
key:                  dhall-yaml-1.2.11-DVZnli2ncUyABm15qqoFRp
license:              GPL-3.0-only
copyright:            2019 Gabriel Gonzalez
maintainer:           Gabriel439@gmail.com
author:               Gabriel Gonzalez
synopsis:             Convert between Dhall and YAML
description:
    Use this package if you want to convert between Dhall expressions and YAML.
    You can use this package as a library or an executable:

    * See the "Dhall.Yaml" module if you want to use this package as a library

    * Use the @dhall-to-yaml-ng@ program from this package if you want an executable

category:             Compiler
abi:                  76630aeefd5c32ef907a01cd345eec24
exposed:              True
exposed-modules:      Dhall.Yaml Dhall.YamlToDhall
import-dirs:          /usr/lib/ghc-9.2.8/site-local/dhall-yaml-1.2.11
library-dirs:         /usr/lib/ghc-9.2.8/site-local/dhall-yaml-1.2.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dhall-yaml
hs-libraries:         HSdhall-yaml-1.2.11-DVZnli2ncUyABm15qqoFRp
depends:
    HsYAML-0.2.1.3-Jv3uHMzrE3uE7yCeoL0Kz
    HsYAML-aeson-0.2.0.1-5xydkwG97W9F8ttRJtR5fD
    aeson-2.1.2.1-7dcOSp8IaGA80HTLJplaly base-4.16.4.0
    bytestring-0.11.4.0 dhall-1.41.2-6pWXjagA63zFX71j1T9v5E
    dhall-json-1.7.11-9l9yxTHMbTQKYXyzET4Ky9
    optparse-applicative-0.17.1.0-Jx8WaQbsFK9BJBRr9ePa2T text-1.2.5.0
    vector-0.13.1.0-BOAscM7GxpQxkvUjpqER4

haddock-interfaces:   /usr/share/doc/dhall-yaml/html/dhall-yaml.haddock
haddock-html:         /usr/share/doc/dhall-yaml/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
